@@ -1,7 +1,8 @@
 import re
 from typing import List
 
-from nonebot.message import Message
+from aiocqhttp.message import Message
+
 from nonebot.typing import Message_T
 
 
@@ -14,8 +15,11 @@ def _extract_text(arg: Message_T) -> str:
 def _extract_image_urls(arg: Message_T) -> List[str]:
     """Extract all image urls from a message-like object."""
     arg_as_msg = Message(arg)
-    return [s.data['url'] for s in arg_as_msg
-            if s.type == 'image' and 'url' in s.data]
+    return [
+        s.data['url']
+        for s in arg_as_msg
+        if s.type == 'image' and 'url' in s.data
+    ]
 
 
 def _extract_numbers(arg: Message_T) -> List[float]:
